@@ -3,22 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -139,7 +136,7 @@
 *     Coefficients for P in gamma approximation over [1,2] in decreasing order.*
 *******************************************************************************/
 
-static double p[8] = { -1.71618513886549492533811e+0,
+static const double p[8] = { -1.71618513886549492533811e+0,
                         2.47656508055759199108314e+1,
                        -3.79804256470945635097577e+2,
                         6.29331155312818442661052e+2,
@@ -152,7 +149,7 @@ static double p[8] = { -1.71618513886549492533811e+0,
 *     Coefficients for Q in gamma approximation over [1,2] in decreasing order.*
 *******************************************************************************/
 
-static double q[8] = { -3.08402300119738975254353e+1,
+static const double q[8] = { -3.08402300119738975254353e+1,
                         3.15350626979604161529144e+2,
                        -1.01515636749021914166146e+3,
                        -3.10777167157231109440444e+3,
@@ -165,7 +162,7 @@ static double q[8] = { -3.08402300119738975254353e+1,
 *     Coefficients for minimax approximation over [12, INF].                   *
 *******************************************************************************/
 
-static double c[7] = { -1.910444077728e-03,
+static const double c[7] = { -1.910444077728e-03,
                         8.4171387781295e-04,
                        -5.952379913043012e-04,
                         7.93650793500350248e-04,
@@ -173,13 +170,13 @@ static double c[7] = { -1.910444077728e-03,
                         8.333333333333333331554247e-02,
                         5.7083835261e-03 };
 
-static double LogSqrt2pi = 0.9189385332046727417803297e+0;
-static double pi         = 3.1415926535897932384626434e+0;
-static double xbig       = 171.624e+0;
-static double MinimumX   = 2.23e-308;
-static double eps        = 2.22e-16;
-static hexdouble Huge    = HEXDOUBLE(0x7ff00000, 0x00000000);
-static double zero	 = 0.0;
+static const double LogSqrt2pi = 0.9189385332046727417803297e+0;
+static const double pi         = 3.1415926535897932384626434e+0;
+static const double xbig       = 171.624e+0;
+static const double MinimumX   = 2.23e-308;
+static const double eps        = 2.22e-16;
+static const hexdouble Huge    = HEXDOUBLE(0x7ff00000, 0x00000000);
+static const double zero	 = 0.0;
 
 #define      GAMMA_NAN      "42"
 #define      SET_INVALID    0x01000000
