@@ -3,22 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -53,7 +50,7 @@
 *        10 Sep 01   ali  added more comments.                                  *
 *        09 Sep 01   ali  added macros to detect PowerPC and correct compiler.  *
 *        06 Sep 01   ram  added #ifdef __ppc__.                                 *
-*        16 Jul 01   ram  Replaced __setflm with fegetenvd/fesetenvd.           *
+*        16 Jul 01   ram  Replaced __setflm with FEGETENVD/FESETENVD.           *
 *                          replaced DblInHex typedef with hexdouble.            *
 *        09 Oct 94   ali  made environmental changes to use __setflm            *
 *                         instead of _feprocentry.                              *
@@ -100,7 +97,7 @@ static const hexsingle HugeFHalved     = { 0x7f000000 };
    low quotient result to the location pointed to by the int pointer
    argument, quo:  -127 <= iquo <= +127.
    
-   This function calls:  __fpclassifyd, logb, scalbn, __fabs, signbitd.
+   This function calls:  __fpclassifyd, logb, scalbn, __FABS, signbitd.
 ***********************************************************************/
 
 #if defined(BUILDING_FOR_CARBONCORE_LEGACY)
@@ -131,13 +128,7 @@ static long int ___fpclassifyd ( double arg )
       }
 }
 
-static double __logb ( double x )
-{
-    asm volatile ("fldl 4(%esp)");
-    asm volatile ("fxtract");
-    asm volatile ("fstp %st");
-    asm volatile ("ret");
-}
+extern double __logb ( double x );
 
 static const double twoTo1023  = 8.988465674311579539e307;   // 0x1p1023
 static const double twoToM1022 = 2.225073858507201383e-308;  // 0x1p-1022
@@ -203,8 +194,8 @@ double remquo ( double x, double y, int *quo)
       iclx = ___fpclassifyd(x);
       icly = ___fpclassifyd(y);
       if ((iclx & icly) >= FP_NORMAL)    {            /* x,y both nonzero finite case */
-         x1 = __fabs(x);                              /* work with absolute values */
-         absy = __fabs(y);
+         x1 = __FABS(x);                              /* work with absolute values */
+         absy = __FABS(y);
          iquo = 0;                                    /* zero local quotient */
          iscx = (long int) __logb(x1);                /* get binary exponents */
          iscy = (long int) __logb(absy);
@@ -281,8 +272,8 @@ float remquof ( float x, float y, int *quo)
       iclx = __fpclassifyf(x);
       icly = __fpclassifyf(y);
       if ((iclx & icly) >= FP_NORMAL)    {            /* x,y both nonzero finite case */
-         x1 = __fabsf(x);                              /* work with absolute values */
-         absy = __fabsf(y);
+         x1 = __FABSF(x);                              /* work with absolute values */
+         absy = __FABSF(y);
          iquo = 0;                                    /* zero local quotient */
          iscx = (long int) logbf(x1);                  /* get binary exponents */
          iscy = (long int) logbf(absy);
