@@ -3,22 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -53,7 +50,7 @@
 *     10 Sep 01  ali added more comments.                                      *
 *     09 Sep 01  ali added macros to detect PowerPC and correct compiler.      *
 *     28 Aug 01  ram  added #ifdef __ppc__.                                    *
-*     13 Jul 01  ram  Replaced __setflm with fegetenvd/fesetenvd.              *
+*     13 Jul 01  ram  Replaced __setflm with FEGETENVD/FESETENVD.              *
 *                            replaced DblInHex typedef with hexdouble.         *
 *     03 Mar 01  ali  first port to os x using gcc, added the crucial          *
 *                       __setflm definition.                                   *
@@ -114,7 +111,6 @@ static const hexsingle HugeF = { 0x7F800000 };
 #define HUGEF HugeF.fval
 
 static const double twoTo52  = 4503599627370496.0;
-static const float twoTo23  = 8388608.0;
 
 /*******************************************************************************
 *                                                                              *
@@ -213,7 +209,7 @@ float roundf ( float x )
       
       argument.fval = x;
       xHead = argument.lval & 0x7fffffff;              // xHead <- |x|
-      target = ( argument.lval < 0x80000000 );         // flag positive sign
+      target = ( (unsigned long)argument.lval < 0x80000000ul );         // flag positive sign
       
       if ( xHead < 0x4b000000ul ) 
 /*******************************************************************************
@@ -387,7 +383,7 @@ long int lroundf ( float x )
        
        argument.fval = x;
        xhi = argument.lval & 0x7fffffff;                    // high 32 bits of x
-       target = ( argument.lval < 0x80000000 );             // flag positive sign
+       target = ( (unsigned long)argument.lval < 0x80000000ul );             // flag positive sign
  
        if ( xhi > 0x4f800000ul ) 
 /*******************************************************************************
@@ -543,7 +539,7 @@ float truncf ( float x )
        
        argument.fval = x;
        xhi = argument.lval & 0x7fffffff;                         // xhi <- |x|
-       target = ( argument.lval < 0x80000000 );                  // flag positive sign
+       target = ( (unsigned long)argument.lval < 0x80000000ul );                  // flag positive sign
        
        if ( xhi < 0x4b000000ul ) 
 /*******************************************************************************
