@@ -3,22 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -91,9 +88,9 @@
 
 #define      INVERSE_HYPERBOLIC_NAN            "40"
 
-static hexdouble SqrtNegEps  = HEXDOUBLE(0x3e400000, 0x00000000); /* = 7.4505805969238281e-09   */
-static hexdouble Log2        = HEXDOUBLE(0x3FE62E42, 0xFEFA39EF); /* = 6.9314718055994530942E-1 */
-static hexdouble FiveFourth  = HEXDOUBLE(0x3FF40000, 0x00000000); /* = 1.250000000000000E+00    */
+static const hexdouble SqrtNegEps  = HEXDOUBLE(0x3e400000, 0x00000000); /* = 7.4505805969238281e-09   */
+static const hexdouble Log2        = HEXDOUBLE(0x3FE62E42, 0xFEFA39EF); /* = 6.9314718055994530942E-1 */
+static const hexdouble FiveFourth  = HEXDOUBLE(0x3FF40000, 0x00000000); /* = 1.250000000000000E+00    */
 
 /*******************************************************************************
 *                  A      R      C      T      A      N      H                 *
@@ -180,8 +177,8 @@ double atanh ( double x )
 #else
 
 static const double kMinNormal = 2.2250738585072014e-308;  // 0x1.0p-1022
-static hexdouble InvSqrtNegEps  = HEXDOUBLE(0x41c00000, 0x00000000); 
-static hexdouble Huge       = HEXDOUBLE(0x7ff00000, 0x00000000);
+static const hexdouble InvSqrtNegEps  = HEXDOUBLE(0x41c00000, 0x00000000); 
+static const hexdouble Huge       = HEXDOUBLE(0x7ff00000, 0x00000000);
 
 double atanh ( double x )
 {
@@ -199,9 +196,9 @@ double atanh ( double x )
       
       FEGETENVD ( FPR_env );
       __ENSURE( FPR_z, FPR_kMinNormal, FPR_sqreps );	__ENSURE( FPR_half, FPR_two, FPR_one );
-      __ENSURE( FPR_z, FPR_inf, FPR_ln2 );
 
       FESETENVD ( FPR_z );
+      __ENSURE( FPR_z, FPR_inf, FPR_ln2 );
       
 /*******************************************************************************
 *                                                                              *
@@ -279,13 +276,6 @@ double atanh ( double x )
       return result;
 }
 #endif
-#ifdef notdef
-float atanhf( float x )
-{
-    return (float)atanh( x );
-}
-#endif
-
 /*******************************************************************************
 *                  A      R      C      S      I      N      H                 *
 *******************************************************************************/
@@ -373,8 +363,8 @@ double asinh ( double x )
       FEGETENVD ( FPR_env );
       __ENSURE( FPR_z, FPR_kMinNormal, FPR_sqreps );
       __ENSURE( FPR_4div3, FPR_two, FPR_one );
-      __ENSURE( FPR_ln2, FPR_inf, FPR_invsqreps );
       FESETENVD ( FPR_z );
+      __ENSURE( FPR_ln2, FPR_inf, FPR_invsqreps );
       
 /*******************************************************************************
 *                                                                              *
@@ -461,13 +451,6 @@ double asinh ( double x )
 }
 #endif
 
-#ifdef notdef
-float asinhf( float x )
-{
-    return (float)asinh( x );
-}
-#endif
-
 /*******************************************************************************
 *                  A      R      C      C      O      S      H                 *
 *******************************************************************************/
@@ -567,9 +550,10 @@ double acosh ( double x )
       FPR_inf = Huge.d;
       
       FEGETENVD ( FPR_env );
-      __ENSURE( FPR_z, FPR_ln2, FPR_invsqreps );	__ENSURE( FPR_z, FPR_inf, FPR_z );
+      __ENSURE( FPR_z, FPR_ln2, FPR_invsqreps );
       __ENSURE( FPR_5div4, FPR_two, FPR_one );
       FESETENVD ( FPR_z );
+      __ENSURE( FPR_z, FPR_inf, FPR_z );
       
       xMinusOne = x - FPR_one;
 
@@ -657,12 +641,6 @@ double acosh ( double x )
       return result;
 }
 #endif
-#ifdef notdef
-float acoshf( float x )
-{
-    return (float)acosh( x );
-}
-#endif
 
 #else       /* __APPLE_CC__ version */
 #warning A higher version than gcc-932 is required.
