@@ -3,22 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -130,13 +127,13 @@
 *     decreasing order.                                                        *
 *******************************************************************************/
 
-static double a[5] = { 3.16112374387056560e+0,
+static const double a[5] = { 3.16112374387056560e+0,
                        1.13864154151050156e+2,
                        3.77485237685302021e+2,
                        3.20937758913846947e+3,
                        1.85777706184603153e-1 };
                        
-static double b[4] = { 2.36012909523441209e+1,
+static const double b[4] = { 2.36012909523441209e+1,
                        2.44024637934444173e+2,
                        1.28261652607737228e+3,
                        2.84423683343917062e+3 };
@@ -146,7 +143,7 @@ static double b[4] = { 2.36012909523441209e+1,
 *     in decreasing order.                                                     *
 *******************************************************************************/
 
-static double c[9] = { 5.64188496988670089e-1,
+static const double c[9] = { 5.64188496988670089e-1,
                        8.88314979438837594e+0,
                        6.61191906371416295e+1,
                        2.98635138197400131e+2,
@@ -156,7 +153,7 @@ static double c[9] = { 5.64188496988670089e-1,
                        1.23033935479799725e+3,
                        2.15311535474403846e-8 };
 
-static double d[8] = { 1.57449261107098347e+1,
+static const double d[8] = { 1.57449261107098347e+1,
                        1.17693950891312499e+2,
                        5.37181101862009858e+2,
                        1.62138957456669019e+3,
@@ -170,23 +167,23 @@ static double d[8] = { 1.57449261107098347e+1,
 *    decreasing order.                                                         *
 *******************************************************************************/
 
-static double p[6] = { 3.05326634961232344e-1,
+static const double p[6] = { 3.05326634961232344e-1,
                        3.60344899949804439e-1,
                        1.25781726111229246e-1,
                        1.60837851487422766e-2,
                        6.58749161529837803e-4,
                        1.63153871373020978e-2 };
 
-static double q[5] = { 2.56852019228982242e+0,
+static const double q[5] = { 2.56852019228982242e+0,
                        1.87295284992346047e+0,
                        5.27905102951428412e-1,
                        6.05183413124413191e-2,
                        2.33520497626869185e-3 };
 
-static double InvSqrtPI = 5.6418958354775628695e-1;
-static double xbig      = 27.2e+0;
-static double Maximum   = 2.53e+307;
-static double _HUGE      = 6.71e+7;
+static const double InvSqrtPI = 5.6418958354775628695e-1;
+static const double xbig      = 27.2e+0;
+static const double Maximum   = 2.53e+307;
+static const double _HUGE      = 6.71e+7;
 
 #pragma fenv_access on
 
@@ -239,13 +236,6 @@ double erf ( double x )
       return ( result );
       }
 
-#ifdef notdef
-float erff ( float x )
-{
-    return (float)erf ( x );
-}
-#endif
-
 /*******************************************************************************
 *        C O M P L E M E N T A R Y    E R R O R    F U N C T I O N             *
 *******************************************************************************/
@@ -295,12 +285,6 @@ double erfc ( double x )
       return ( result );
       }
 
-#ifdef notdef
-float erfcf ( float x )
-{
-    return (float)erfc ( x );
-}
-#endif
 
 /*******************************************************************************
 *            C  O  R  E    A  P  P  R  O  X  I  M  A  T  I  O  N               *
