@@ -3,22 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -162,11 +159,11 @@ static long int ___fpclassifyd ( double arg )
 
 static double __nextafter ( double x, double y )
       {
-      static hexdouble EPSILON = HEXDOUBLE(0x00000000, 0x00000001);
-      static hexdouble PosINF  = HEXDOUBLE(0x7ff00000, 0x00000000);
-      static hexdouble NegINF  = HEXDOUBLE(0xfff00000, 0x00000000);
-      static hexdouble PosBig  = HEXDOUBLE(0x7fefffff, 0xffffffff);
-      static hexdouble NegBig  = HEXDOUBLE(0xffefffff, 0xffffffff);
+      static const hexdouble EPSILON = HEXDOUBLE(0x00000000, 0x00000001);
+      static const hexdouble PosINF  = HEXDOUBLE(0x7ff00000, 0x00000000);
+      static const hexdouble NegINF  = HEXDOUBLE(0xfff00000, 0x00000000);
+      static const hexdouble PosBig  = HEXDOUBLE(0x7fefffff, 0xffffffff);
+      static const hexdouble NegBig  = HEXDOUBLE(0xffefffff, 0xffffffff);
       double arg;
       hexdouble      temp, xsign, ysign;
       register int newexc;
@@ -288,11 +285,11 @@ double nextafterd(double x, double y)
 
 float nextafterf ( float x, float y )
       {
-      static hexsingle EPSILON = { 0x00000001 };
-      static hexsingle PosINF  = { 0x7f800000 };
-      static hexsingle NegINF  = { 0xff800000 };
-      static hexsingle PosBig  = { 0x7f7fffff };
-      static hexsingle NegBig  = { 0xff7fffff };
+      static const hexsingle EPSILON = { 0x00000001 };
+      static const hexsingle PosINF  = { 0x7f800000 };
+      static const hexsingle NegINF  = { 0xff800000 };
+      static const hexsingle PosBig  = { 0x7f7fffff };
+      static const hexsingle NegBig  = { 0xff7fffff };
       double arg;
       hexdouble      temp;
       hexsingle      xsign, ysign;
