@@ -3,22 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -87,8 +84,8 @@
 *     __fpclassifyd, copysign, exp, expm1 and __FABS.                          *
 *******************************************************************************/
 
-static hexdouble SqrtNegEps = HEXDOUBLE(0x3e400000, 0x00000000); 
-static hexdouble Huge       = HEXDOUBLE(0x7ff00000, 0x00000000);
+static const hexdouble SqrtNegEps = HEXDOUBLE(0x3e400000, 0x00000000); 
+static const hexdouble Huge       = HEXDOUBLE(0x7ff00000, 0x00000000);
 static const double kMinNormal = 2.2250738585072014e-308;  // 0x1.0p-1022
 
 
@@ -137,7 +134,7 @@ double sinh ( double x )
       }
 #else
 
-static hexdouble Log2        = HEXDOUBLE(0x3FE62E42, 0xFEFA39EF); /* = 6.9314718055994530942E-1 */
+static const hexdouble Log2        = HEXDOUBLE(0x3FE62E42, 0xFEFA39EF); /* = 6.9314718055994530942E-1 */
 static const double kMaxNormal = 1.7976931348623157e308;
 
 double sinh ( double x )
@@ -154,9 +151,9 @@ double sinh ( double x )
       FPR_ln2 = Log2.d;				FPR_kMaxNormal = kMaxNormal;
       
       FEGETENVD ( FPR_env);
-      __ENSURE( FPR_z, FPR_one, FPR_inf );	__ENSURE( FPR_half, FPR_sqreps, FPR_kMinNormal );
-      __ENSURE( FPR_z, FPR_kMaxNormal, FPR_ln2 );
+      __ENSURE( FPR_half, FPR_sqreps, FPR_kMinNormal ); __ENSURE( FPR_z, FPR_kMaxNormal, FPR_ln2 );
       FESETENVD ( FPR_z );
+      __ENSURE( FPR_z, FPR_one, FPR_inf );
 
       if ( PositiveX > FPR_sqreps )       	/* return the arg if too small  */
       {                  
@@ -187,13 +184,6 @@ double sinh ( double x )
 }
 #endif
       
-#ifdef notdef
-float sinhf( float x)
-{
-    return (float)sinh( x );
-}
-#endif
-      
 /*******************************************************************************
 *                              C      O      S      H                          *
 *******************************************************************************/
@@ -242,13 +232,6 @@ double cosh ( double x )
 }
 #endif
 
-#ifdef notdef
-float coshf( float x)
-{
-    return (float)cosh( x );
-}
-#endif
-      
 /*******************************************************************************
 *     This function is odd.  The positive interval is computed and for         *
 *     negative values, the sign is reflected in the computation.               *
@@ -329,9 +312,9 @@ double tanh ( double x )
             return (x >= FPR_z ? 1.0 : -1.0);
 
       FEGETENVD ( FPR_env );
-      __ENSURE( FPR_z, FPR_inf, FPR_two );	__ENSURE( FPR_negTwo, FPR_sqreps, FPR_kMinNormal );
-      __ENSURE( FPR_z, FPR_kMaxNormal, FPR_ln2 );
+      __ENSURE( FPR_negTwo, FPR_sqreps, FPR_kMinNormal ); __ENSURE( FPR_z, FPR_kMaxNormal, FPR_ln2 );
       FESETENVD ( FPR_z );
+      __ENSURE( FPR_z, FPR_inf, FPR_two );
 
 /*******************************************************************************
 *     Reduce the number of calls to expm1 function by using the identity:      *
@@ -372,13 +355,6 @@ double tanh ( double x )
 }
 #endif
 
-#ifdef notdef
-float tanhf( float x)
-{
-    return (float)tanh( x );
-}
-#endif
-      
 #else       /* __APPLE_CC__ version */
 #warning A higher version than gcc-932 is required.
 #endif      /* __APPLE_CC__ version */
