@@ -3,22 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -300,9 +297,10 @@ double __sqrt ( double x )
       FEGETENVD( OldEnvironment );               	// save environment, set default
       
       __ORI_NOOP;
-      __ENSURE( FPR_z, FPR_inf, FPR_Two911 );    	__ENSURE( FPR_TwoM128, FPR_Two128, FPR_HalfULP );
+      __ENSURE( FPR_TwoM128, FPR_Two128, FPR_z );
       
        FESETENVD( FPR_z );
+       __ENSURE( FPR_HalfULP, FPR_inf, FPR_Two911 );
     
 /*******************************************************************************
 *     Special case for GPUL: storing and loading floats avoids L/S hazard  
@@ -500,151 +498,6 @@ double __sqrt ( double x )
 
 #endif
 
-#ifdef notdef
-/*******************************************************************************
-*     									       *
-*     Single Precision Implementation.					       *
-*     									       *
-*******************************************************************************/
-
-#undef	     upHalfOfAnULP
-#define      upHalfOfAnULP      0.50000006         	 // 0x1.000002p-1
-#define      twoTo64            0.1844674407370955e20    // 2**64    
-#define      twoToMinus32      	0.2328306436538696e-9    // 2**-32
-
-float sqrtf ( float x )
-      {
-      register int index;
-      hexdouble OldEnvironment;
-      hexsingle xInHex, yInHex, gInHex;
-      register float g, y, y2, d, e;
-      register unsigned long int xhead, ghead, yhead;
-            
-      xInHex.fval = x;
-      xhead = xInHex.lval;                         // 32 bits of x
-      FEGETENVD( OldEnvironment.d );               // save environment, set default
-      FESETENVD( 0.0 );
-    
-/*******************************************************************************
-*      > x  0.0.  This section includes +0.0, but not -0.0.                  *
-*******************************************************************************/
-
-      if ( xhead < 0x7f800000 ) 
-            {
-
-/*******************************************************************************
-*     First and most common section: argument > 2.0^(-76), about 0.1323488e-22.*
-*******************************************************************************/
-            
-            if ( xhead > 0x1a000000ul )
-                  {
-
-/*******************************************************************************
-*     Calculate initial estimates for g and y from x and SqrtTable[].          *
-*******************************************************************************/
-
-                  ghead = ( ( xhead + 0x3f800000 ) >> 1 ) & 0x7f800000;
-                  index = ( xhead >> 16 ) & 0xffUL; // table index
-                  yhead = 0x7e000000UL - ghead;
-                  gInHex.lval = ghead + ( ( 0xff00UL & SqrtTable[index] ) << 7 );
-                  yInHex.lval = yhead + ( ( 0xffUL & SqrtTable[index] ) << 15 );
-                  g = gInHex.fval;
-                  y = yInHex.fval;
-      
-/*******************************************************************************
-*     Iterate to refine both g and y.                                          *
-*******************************************************************************/
-
-                  d = x - g * g;
-                  y2 = y + y;
-                  g = g + y * d;                   //   16-bit g
-                  e = upHalfOfAnULP - y * g;
-                  d = x - g * g;
-                  y = y + e * y2;                  //   16-bit y
-                  g = g + y * d;                   //   32-bit g before rounding
-                  y2 = y + y;
-                  e = upHalfOfAnULP - y * g;
-                  d = x - g * g;
-                  y = y + e * y2;                  //   32-bit y
-                  FESETENVD( OldEnvironment.d );   //   restore caller's environment
-                  return ( g + y * d );            //   final step
-                  }
-
-/*******************************************************************************
-*     Second section: 0.0 < argument < 2.0^(-76) which is about 0.1323488e-22. *
-*     Identical to the previous segment aside from 2^64 scale factor.          *
-*******************************************************************************/
-
-            if ( xhead != 0UL ) 
-                  { 
-                  xInHex.fval = x * twoTo64;         //   scale up by 2^64
-                  xhead = xInHex.lval;
-
-/*******************************************************************************
-*     Calculate initial estimates for g and y from x and SqrtTable[].          *
-*******************************************************************************/
-
-                  ghead = ( ( xhead + 0x3f800000 ) >> 1 ) & 0x7f800000;
-                  index = ( xhead >> 16 ) & 0xffUL; // table index
-                  yhead = 0x7e000000UL - ghead;
-                  gInHex.lval = ghead + ( ( 0xff00UL & SqrtTable[index] ) << 7 );
-                  yInHex.lval = yhead + ( ( 0xffUL & SqrtTable[index] ) << 15 );
-                  x = xInHex.fval;
-                  g = gInHex.fval;
-                  y = yInHex.fval;
-
-/*******************************************************************************
-*     Iterate to refine both g and y.                                          *
-*******************************************************************************/
-            
-                  d = x - g * g;
-                  y2 = y + y;
-                  g = g + y * d;                   //   16-bit g
-                  e = upHalfOfAnULP - y * g;
-                  d = x - g * g;
-                  y = y + e * y2;                  //   16-bit y
-                  g = g + y * d;                   //   32-bit g before rounding
-                  y2 = y + y;
-                  e = upHalfOfAnULP - y * g;
-                  d = x - g * g;
-                  y = y + e * y2;                  //   32-bit y
-                  g *= twoToMinus32;               //   undo scaling
-                  d *= twoToMinus32;
-                  FESETENVD( OldEnvironment.d );   //   restore caller's environment
-                  return ( g + y * d );            //   final step            
-                  }
-
-/*******************************************************************************
-*     Third section: handle x = +0.0 that slipped through.                     *
-*******************************************************************************/
-
-            else 
-                  {                                // x = +0.0
-                  FESETENVD( OldEnvironment.d );   //   restore caller's environment
-                  return ( x );
-                  }
-            }
-/*******************************************************************************
-*     Fourth section: special cases: argument is +INF, NaN, -0.0, or <0.       *
-*******************************************************************************/
-   
-      FESETENVD( OldEnvironment.d );               //   restore caller's environment
-
-      if ( xhead < 0x80000000 )                    // x is +NaN or +INF
-            return ( x );
-
-      if ( ( x == 0.0 ) || ( x != x ) )            // return -0.0 or -NaN argument
-            return x;
-      else                                         // negative x is INVALID
-            {
-            x = nan ( SQRT_NAN );
-            OldEnvironment.i.lo |= SET_INVALID;
-            FESETENVD( OldEnvironment.d );         //   restore caller's environment
-            return ( x );                          // return NAN
-            }
-      }
-#endif /* notdef */
-
 #else       /* __APPLE_CC__ version */
 #warning A higher version than gcc-932 is required.
 #endif      /* __APPLE_CC__ version */
