@@ -3,22 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -380,13 +377,6 @@ double exp ( double x )
 }
 #endif
 
-#ifdef notdef
-float expf( float x)
-{
-    return (float)exp( x );
-}
-#endif
-
 /*******************************************************************************
 *                                                                              *
 *    The expm1 function.  						       *
@@ -716,13 +706,6 @@ double expm1 ( double x )
 }
 #endif
 
-#ifdef notdef
-float expm1f( float x )
-{
-    return (float)expm1( x );
-}
-#endif
-
 #else /* BUILDING_FOR_CARBONCORE_LEGACY */
 
 /*******************************************************************************
@@ -1002,13 +985,6 @@ double exp2 ( double x )
 }
 #endif
 
-#ifdef notdef
-float exp2f( float x)
-{
-    return (float)exp2( x );
-}
-#endif
-
 #endif /* BUILDING_FOR_CARBONCORE_LEGACY */
 
 #else       /* __APPLE_CC__ version */
