@@ -3,22 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -497,13 +494,6 @@ double log ( double x )
 }
 #endif
 
-#ifdef notdef
-float logf ( float x )
-{
-    return (float)log( x );
-}
-#endif
-
 /*******************************************************************************
 *                                                                              *
 *    The base 10 logorithm function.  Callers rounding direction is honored.  *
@@ -893,13 +883,6 @@ double log10 ( double x )
 }
 #endif
 
-#ifdef notdef
-float log10f ( float x )
-{
-    return (float)log10( x );
-}
-#endif
-
 /*******************************************************************************
 *                                                                              *
 *    The base e log(1+x) function.  Callers rounding direction is honored.    *
@@ -1207,13 +1190,6 @@ double log1p ( double x )
 }
 #endif
 
-#ifdef notdef
-float log1pf ( float x )
-{
-    return (float)log1p( x );
-}
-#endif
-
 #else /* BUILDING_FOR_CARBONCORE_LEGACY */
 
 /*******************************************************************************
@@ -1497,13 +1473,6 @@ double log2 ( double x )
 }
 #endif
 
-#ifdef notdef
-float log2f ( float x )
-{
-    return (float)log2( x );
-}
-#endif
-
 #endif /* BUILDING_FOR_CARBONCORE_LEGACY */
 
 #else       /* __APPLE_CC__ version */
