@@ -3,22 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -117,7 +114,7 @@ double tan (   double x  )
                    tt5  = 0.1333333333304691192925,
                    tt3  = 0.3333333333333333357614;
       const double k2ToM1023 = 1.112536929253600692e-308; // 0x1.0p-1023
-      static long indexTable[] =
+      static const long indexTable[] =
             {  
             16,  17,  18,  19,  20,  21,  22,  23,  24,  25,  26,
             27,  28,  29,  30,  31,  32,  33,  34,  35,  36,  37,
@@ -426,7 +423,7 @@ static const double tt7  = 0.05396875452473400572649,
             tt5  = 0.1333333333304691192925,
             tt3  = 0.3333333333333333357614;
 static const double k2ToM1023 = 1.112536929253600692e-308; // 0x1.0p-1023
-static long indexTable[] =
+static const long indexTable[] =
     {  
     16,  17,  18,  19,  20,  21,  22,  23,  24,  25,  26,
     27,  28,  29,  30,  31,  32,  33,  34,  35,  36,  37,
@@ -837,12 +834,6 @@ double tan (   double x  )
       }
 }
 #endif
-#ifdef notdef
-float tanf( float x )
-{
-    return (float)tan( x );
-}
-#endif
 
 #else       /* __APPLE_CC__ version */
 #warning A higher version than gcc-932 is required.
